##  In This Section
  * [Dashboards](https://help.sap.com/docs/leanix/ea/dashboards?locale=en-US&state=PRODUCTION&version=CLOUD "Dashboards enable you to consolidate and interpret data in one place, facilitating informed decision-making and promoting efficient task management. Learn how to create, customize, and manage dashboards.")
  * [Inventory](https://help.sap.com/docs/leanix/ea/inventory?locale=en-US&state=PRODUCTION&version=CLOUD "The inventory is your centralized repository for managing and documenting enterprise architecture objects. You create, edit, and organize fact sheets to maintain an accurate depiction of your IT landscape. It is the go-to place for anyone seeking information from the fact sheets.")
  * [Reports](https://help.sap.com/docs/leanix/ea/reports?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [Diagrams](https://help.sap.com/docs/leanix/ea/diagrams?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [Collaboration](https://help.sap.com/docs/leanix/ea/collaboration?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers several robust collaboration features, such as surveys, to-dos, comments, fact sheet subscriptions, and comments, to make stakeholder participation easier in enriching and validating data, and thereby ensuring data quality and completeness.")
  * [AI Capabilities](https://help.sap.com/docs/leanix/ea/ai-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD "AI capabilities in SAP LeanIX automate documentation tasks, offer contextual insights, and support natural language queries to streamline enterprise architecture management. Use it to boost efficiency, reduce manual work, and maintain compliance with data privacy and ethical standards.")
  * [AI Agent Hub](https://help.sap.com/docs/leanix/ea/ai-agent-hub?locale=en-US&state=PRODUCTION&version=CLOUD "Discover and manage AI agents across the organization.")
  * [MCP Server](https://help.sap.com/docs/leanix/ea/mcp-server?locale=en-US&state=PRODUCTION&version=CLOUD "Connect external AI applications to SAP LeanIX using the Model Context Protocol \(MCP\) server to securely access enterprise architecture data.")
  * [Workspace Views](https://help.sap.com/docs/leanix/ea/workspace-views?locale=en-US&state=PRODUCTION&version=CLOUD "Use workspace views configured by admins to limit the scope of displayed information and focus on your current tasks.")
  * [Presentations](https://help.sap.com/docs/leanix/ea/presentations?locale=en-US&state=PRODUCTION&version=CLOUD "Use presentations to share enterprise architecture insights from reports and diagrams with your organization, without the need to export data to external presentation tools.")
  * [Collections](https://help.sap.com/docs/leanix/ea/collections?locale=en-US&state=PRODUCTION&version=CLOUD "Use collections to arrange dashboards, reports, and diagrams into custom groups.")
  * [Notifications](https://help.sap.com/docs/leanix/ea/notifications?locale=en-US&state=PRODUCTION&version=CLOUD "Adjust your notification preferences to stay informed about significant changes in your workspace, monitor tasks that need your attention, and stay updated on other relevant activities.")
  * [User Profile](https://help.sap.com/docs/leanix/ea/user-profile?locale=en-US&state=PRODUCTION&version=CLOUD "Manage your user profile settings. Change or reset your password if needed.")


YesNo
Send
